@@ -1,12 +1,11 @@
 OC.L10N.register(
     "contacts",
     {
-    "Contacts" : "Kontakte",
     "All contacts" : "Alle kontakte",
     "Details" : "Details",
+    "Contacts" : "Kontakte",
     "A contacts app for Nextcloud" : "’n Kontakte-toep vir Nextcloud",
     "Invalid image" : "Ongeldige beeld",
-    "Loading" : "Laai tans..",
     "Name" : "Naam",
     "Company" : "Maatskappy",
     "Title" : "Titel",
@@ -15,6 +14,7 @@ OC.L10N.register(
     "Cancel" : "Kanselleer",
     "Groups" : "Groepe",
     "New contact" : "Nuwe kontak",
+    "Loading …" : "Laai …",
     "Select type" : "Kies tipe",
     "Select Date" : "Kies Datum",
     "Last modified" : "Laas gewysig",
@@ -30,7 +30,10 @@ OC.L10N.register(
     "First name" : "Naam",
     "Last name" : "Van",
     "Display name" : "Vertoonnaam",
+    "Group name" : "Groepnaam",
     "Not grouped" : "Nie gegroepeer",
+    "Close" : "Sluit",
+    "Import" : "Voer In",
     "Nickname" : "Bynaam",
     "Detailed name" : "Gedetailleerde naam",
     "Additional names" : "Addisionele name",
@@ -78,8 +81,6 @@ OC.L10N.register(
     "Colleague" : "Kollega",
     "Manager" : "Bestuurder",
     "Assistant" : "Assistent",
-    "Related" : "Verwant",
-    "Specify a relationship between another entity and the entity represented by this vCard." : "Spesifiseer ’n verhouding tussen ’n ander entiteit en die entiteit wat deur hierdie vCard verteenwoordig word.",
     "Contact" : "Kontak",
     "Agent" : "Agent",
     "Emergency" : "Noodgeval",
@@ -89,7 +90,6 @@ OC.L10N.register(
     "Male" : "Manlik",
     "None" : "Geen",
     "Unknown" : "Onbekend",
-    "Timezone" : "Tydsone",
-    "An error occurred" : "'n Fout het voorgekom"
+    "Timezone" : "Tydsone"
 },
 "nplurals=2; plural=(n != 1);");
