@@ -1,10 +1,9 @@
 OC.L10N.register(
     "contacts",
     {
-    "Contacts" : "পরিচিতজন",
     "Details" : "বিসতারিত",
+    "Contacts" : "পরিচিতজন",
     "Invalid image" : "অবৈধ চিত্র",
-    "Loading" : "Loading",
     "Name" : "নাম",
     "Title" : "শিরোনাম",
     "Download" : "ডাউনলোড",
@@ -19,7 +18,10 @@ OC.L10N.register(
     "can edit" : "সম্পাদনা করতে পারবেন",
     "First name" : "নামের প্রথমাংশ ",
     "Last name" : "নামের শেষাংশ",
+    "Group name" : "গ্রুপের নাম",
     "Not grouped" : "দলবদ্ধ নয়",
+    "Close" : "বন্ধ",
+    "Import" : "আমদানি",
     "Nickname" : "ছদ্মনাম",
     "Additional names" : "অতিরিক্ত নামসমূহ",
     "Notes" : "নোট",
