@@ -1,10 +1,9 @@
 OC.L10N.register(
     "contacts",
     {
-    "Contacts" : "Kontakter",
     "Details" : "Detailer",
+    "Contacts" : "Kontakter",
     "Invalid image" : "Ongülteg d'Bild",
-    "Loading" : "Loading",
     "Name" : "Numm",
     "Title" : "Titel",
     "Download" : "Eroflueden",
@@ -19,6 +18,9 @@ OC.L10N.register(
     "can edit" : "kann änneren",
     "First name" : "Virnumm",
     "Last name" : "Famillje Numm",
+    "Group name" : "Gruppe Numm",
+    "Close" : "Zoumaachen",
+    "Import" : "Importéieren",
     "Nickname" : "Spëtznumm",
     "Additional names" : "Weider Nimm",
     "Notes" : "Notizen",
