@@ -8,16 +8,22 @@ OC.L10N.register(
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "“日历”是 Nextcloud CalDav 服务器的一个用户界面应用。通过使用此应用，您可以在不同的设备上同步您的活动并进行在线编辑。\n\n* 🚀 **集成了其他的 Nextcloud 应用！** 现在仅仅集成了联系人功能 - 将来将会集成更多。\n* 🌐 **支持WebCal！** 想要在您的日历上看到您最喜爱的球队的比赛时间？没问题！\n* 🙋 **参与人功能！** 邀请他人参与您的活动。\n* 🙈 **我们不是在做无用功！** 基于出色的 [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) 和 [fullcalendar](https://github.com/fullcalendar/fullcalendar) 库开发.",
     "Copy to full name" : "复制到全名",
     "Omit year" : "忽略年份",
+    "Allow updating avatars from social media" : "允许从社交媒体资料更新头像",
     "Add new property" : "新增属性",
     "Choose property type" : "选择属性类型",
     "Upload a new picture" : "上传一张新的图片",
-    "Choose from files" : "从文件中选择",
+    "Choose from Files" : "从文件中选择",
+    "Get from " : "获取自",
     "Download picture" : "下载图片",
     "Delete picture" : "删除图片",
+    "Choose from files" : "从文件中选择",
     "Invalid image" : "无效的图像",
     "Image is too big (max 1MB)." : "图片过大(最大1MB)",
     "Pick an avatar" : "选择一个头像",
     "Error while processing the picture." : "处理图片时出错。",
+    "Avatar downloaded from social network" : "已从社交媒体下载头像",
+    "Avatar already up to date" : "头像已是最新",
+    "Avatar download failed" : "头像下载失败",
     "No contact selected" : "请选择联系人",
     "Select a contact on the list to begin" : "请先在列表里选择联系人",
     "Name" : "名称",
@@ -28,6 +34,7 @@ OC.L10N.register(
     "Clone contact" : "克隆联系人",
     "Generate QR Code" : "生成二维码",
     "Delete" : "删除",
+    "Contact vCard as qrcode" : "联系人名片二维码",
     "Pick an address book" : "选择一个地址簿",
     "Select address book" : "选择地址簿",
     "Cancel" : "取消",
@@ -39,8 +46,16 @@ OC.L10N.register(
     "New contact" : "新建联系人",
     "Syntax error. Cannot open the contact." : "语法错误。不能打开联系人。",
     "The contact doesn't exists anymore on the server." : "此联系人不再存在于此服务器上。",
+    "Unable to retrieve the contact from the server, please check your network connection." : "无法从服务器取回联系人，请检查你的网络连接。",
+    "An error occurred while trying to move the contact" : "尝试移动联系人时出错",
+    "An error occurred while trying to copy the contact" : "尝试复制联系人时出错",
+    "Remove {type}" : "移除 {类型}",
+    "Search {types}" : "搜索 {类型}",
     "Loading …" : "正在加载…",
+    "List is empty" : "列表是空的",
     "No results" : "无结果",
+    "Add to group" : "添加到群组",
+    "Add {type}" : "添加  {类型}",
     "Select type" : "选择类型",
     "Select Date" : "选择日期",
     "Add contact in group" : "添加联系人到群组",
@@ -52,29 +67,54 @@ OC.L10N.register(
     "Copied" : "已复制",
     "Can not copy" : "无法复制",
     "Copy link" : "复制链接",
+    "Toggling of address book was not successful" : "通讯录切换不成功",
+    "This will delete the address book and every contacts within it" : "这将删除通讯录和其中的每个联系人",
     "Delete {addressbook} ?" : "删除 {addressbook} ？",
+    "Deletion of address book was not successful." : "通讯录删除不成功",
+    "Renaming of address book was not successful." : "通讯录重命名不成功",
+    "Address book copied to clipboard" : "已复制通讯录到剪贴板",
+    "Address book was not copied to clipboard." : "通讯录未被复制到剪贴板。",
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
     "Share with users or groups" : "和用户或者组群共享",
     "No users or groups" : "无用户或群组",
     "can edit" : "可编辑",
+    "Unable to delete the share" : "无法删除共享",
+    "Unable to change permissions" : "无法更改权限",
     "Import contacts" : "导入联系人",
+    "Import into the {addressbookName} addressbook" : "导入到 {addressbookName} 通讯录中",
     "Select local file" : "选择本地文件",
     "Import from files" : "从文件导入",
     "Importing is disabled because there are no address books available" : "导入已被禁用，因为没有可用的地址簿",
     "Choose a vCard file to import" : "选择要导入的 vCard（电子名片） 文件",
     "Address book name" : "地址簿名称",
+    "An error occurred, unable to create the address book" : "发生错误，无法创建通讯录",
     "First name" : "名",
     "Last name" : "姓",
+    "Phonetic first name" : "语音名字",
+    "Phonetic last name" : "语音姓氏",
     "Display name" : "显示名称",
     "Sort by {sorting}" : "以 {sorting} 排序",
+    "Update avatars from social media" : "从社交媒体更新头像",
+    "(refreshed once per week)" : "(每周刷新)",
     "Add contacts" : "添加联系人",
+    "+ New group" : "+ 新群组",
+    "Create a new group" : "新建一个群组",
     "Group name" : "分组名称",
     "Loading contacts …" : "加载联系人…",
+    "There are no contacts yet" : "尚无联系人",
+    "Create contact" : "创建联系人",
+    "There are no contacts in this group" : "该群组中没有联系人",
+    "Create contacts" : "新建联系人",
     "Not grouped" : "未分组",
     "Recently contacted" : "最近联系",
     "Unable to create the contact." : "未能成功创建联系人。",
     "Contact not found" : "未找到联系人",
+    "Group not found" : "找不到群组",
+    "This group already exists" : "该群组已存在",
     "Close" : "关闭",
+    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 位联系人已添加到 {name}"],
+    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["正在添加 {success} 位联系人到 {name}"],
+    "_{count} error_::_{count} errors_" : ["{count} 个错误"],
     "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在导入 %n 个联系人到 {addressbook}"],
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["已将 %n 个联系人导入到 {addressbook}"],
     "Import" : "导入",
@@ -114,6 +154,7 @@ OC.L10N.register(
     "Car" : "车",
     "Work pager" : "工作传呼机",
     "Social network" : "社交网络",
+    "Relationship to you" : "和您的关系",
     "Spouse" : "配偶",
     "Child" : "子女",
     "Mother" : "母亲",
@@ -126,6 +167,7 @@ OC.L10N.register(
     "Colleague" : "同事",
     "Manager" : "经理",
     "Assistant" : "助理",
+    "Related contacts" : "相关联系人",
     "Contact" : "联系",
     "Agent" : "代理",
     "Emergency" : "紧急",
@@ -138,6 +180,7 @@ OC.L10N.register(
     "Timezone" : "时区",
     "Spoken languages" : "口语",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 个联系人读取失败"],
+    "Unable to delete contact" : "无法删除联系人",
     "Your web browser is out of date" : "您的浏览器版本太旧",
     "This application is not compatible with Internet Explorer" : "此应用与Internet Explorer不兼容"
 },
