@@ -33,19 +33,23 @@ class CompositeSocialProvider {
 
 	public function __construct(InstagramProvider $instagramProvider,
 								MastodonProvider $mastodonProvider,
-								FacebookProvider $facebookProvider,
 								TwitterProvider $twitterProvider,
+								// FacebookProvider $facebookProvider,
 								TumblrProvider $tumblrProvider,
-								DiasporaProvider $diasporaProvider) {
+								DiasporaProvider $diasporaProvider,
+								XingProvider $xingProvider,
+								GravatarProvider $gravatarProvider) {
 
 		// This determines the priority of known providers
 		$this->providers = [
-			'instagram' => $instagramProvider,
-			'mastodon'  => $mastodonProvider,
-			'twitter'   => $twitterProvider,
-			'facebook'  => $facebookProvider,
-			'tumblr'    => $tumblrProvider,
-			'diaspora'  => $diasporaProvider,
+			$instagramProvider->name  => $instagramProvider,
+			$mastodonProvider->name   => $mastodonProvider,
+			$twitterProvider->name    => $twitterProvider,
+			// $facebookProvider->name   => $facebookProvider,
+			$tumblrProvider->name     => $tumblrProvider,
+			$diasporaProvider->name   => $diasporaProvider,
+			$xingProvider->name       => $xingProvider,
+			$gravatarProvider->name   => $gravatarProvider
 		];
 	}
 
@@ -58,40 +62,28 @@ class CompositeSocialProvider {
 		return array_keys($this->providers);
 	}
 
+	/**
+	 * generate download url for a social entry
+	 *
+	 * @param String network the choice which network to use
+	 *
+	 * @return ISocialProvider if provider of 'network' is found, otherwise null
+	 */
+	public function getSocialConnector(string $network) : ?ISocialProvider {
+		$connector = null;
+		// check if dedicated network selected
+		if (isset($this->providers[$network])) {
+			$connector = $this->providers[$network];
+		}
+		return $connector;
+	}
 
 	/**
 	 * generate download url for a social entry
 	 *
-	 * @param array socialEntries all social data from the contact
-	 * @param String network the choice which network to use (fallback: take first available)
-	 *
-	 * @returns String the url to the requested information or null in case of errors
+	 * @return ISocialProvider[] all social providers
 	 */
-	public function getSocialConnector(array $socialEntries, string $network) : ?string {
-		$connector = null;
-		$selection = $this->providers;
-		// check if dedicated network selected
-		if (isset($this->providers[$network])) {
-			$selection = [$network => $this->providers[$network]];
-		}
-
-		// check selected providers in order
-		foreach ($selection as $type => $socialProvider) {
-
-			// search for this network in user's profile
-			foreach ($socialEntries as $socialEntry) {
-				if (strtolower($type) === strtolower($socialEntry['type'])) {
-					$profileId = $socialProvider->cleanupId($socialEntry['value']);
-					if (!is_null($profileId)) {
-						$connector = $socialProvider->getImageUrl($profileId);
-					}
-					break;
-				}
-			}
-			if ($connector) {
-				break;
-			}
-		}
-		return ($connector);
+	public function getSocialConnectors() : array {
+		return array_values($this->providers);
 	}
 }
